@@ -1,35 +1,30 @@
 /*
-** Zabbix
-** Copyright 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-**     http://www.apache.org/licenses/LICENSE-2.0
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package plugin
 
 import (
 	"context"
+	"errors"
 	"net/http"
-	"net/url"
 	"time"
 
-	"git.zabbix.com/ap/plugin-support/tlsconfig"
-	"git.zabbix.com/ap/plugin-support/uri"
-	"git.zabbix.com/ap/plugin-support/zbxerr"
-
 	"github.com/omeid/go-yarn"
-
-	"git.zabbix.com/ap/plugin-support/plugin"
+	"golang.zabbix.com/sdk/errs"
+	"golang.zabbix.com/sdk/metric"
+	"golang.zabbix.com/sdk/plugin"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 const (
@@ -49,21 +44,20 @@ type Plugin struct {
 var Impl Plugin
 
 // Export implements the Exporter interface.
-func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result interface{}, err error) {
-	params, extraParams, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
+//
+//nolint:gocyclo,cyclop
+func (p *Plugin) Export(key string, rawParams []string, pluginCtx plugin.ContextProvider) (any, error) {
+	params, extraParams, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
 	}
 
-	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
-		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
+	err = metric.SetDefaults(params, hc, p.options.Default)
 	if err != nil {
-		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
+		return nil, err
 	}
 
-	dbname := url.QueryEscape(params["Database"])
-
-	uri, err := uri.NewWithCreds(params["URI"]+"?dbname="+dbname, params["User"], params["Password"], uriDefaults)
+	connID, err := createConnID(params)
 	if err != nil {
 		return nil, err
 	}
@@ -73,7 +67,7 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(*uri, details)
+	conn, err := p.connMgr.GetConnection(connID, params)
 	if err != nil {
 		// Special logic of processing connection errors should be used if pgsql.ping is requested
 		// because it must return pingFailed if any error occurred.
@@ -86,13 +80,31 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 		return nil, err
 	}
 
-	ctx, cancel := context.WithTimeout(conn.ctx, conn.callTimeout)
+	timeout := conn.callTimeout
+
+	if timeout < time.Second*time.Duration(pluginCtx.Timeout()) {
+		timeout = time.Second * time.Duration(pluginCtx.Timeout())
+	}
+
+	handlerCtx, cancel := context.WithTimeout(conn.ctx, timeout)
 	defer cancel()
 
-	result, err = handleMetric(ctx, conn, key, params, extraParams...)
-
+	result, err := handleMetric(handlerCtx, conn, key, params, extraParams...)
 	if err != nil {
-		p.Errf(err.Error())
+		ctxErr := handlerCtx.Err()
+		if ctxErr != nil && errors.Is(ctxErr, context.DeadlineExceeded) {
+			p.Errf(
+				"failed to handle metric: query execution timeout %s exceeded: %s",
+				timeout.String(),
+				err.Error(),
+			)
+
+			return nil, errs.New("query execution timeout exceeded")
+		}
+
+		p.Errf("failed to handle metric %q: %s", key, err.Error())
+
+		return nil, err
 	}
 
 	return result, err
